@@ -5,7 +5,6 @@ from rich.console import Console
 from rich.markdown import Markdown
 from rich.panel import Panel
 from rich.live import Live
-from rich.status import Status
 import os
 import json
 import sys
@@ -14,7 +13,8 @@ from prompt_toolkit import prompt
 from pathlib import Path
 import pyperclip
 import time
-
+import requests
+import climage
 
 class GPTerminator:
     def __init__(self):
@@ -45,18 +45,17 @@ class GPTerminator:
         self.console = Console()
 
     def getConfigPath(self):
-        if 'APPDATA' in os.environ:
-            confighome = os.environ['APPDATA']
-        elif 'XDG_CONFIG_HOME' in os.environ:
-            confighome = os.environ['XDG_CONFIG_HOME']
+        if "APPDATA" in os.environ:
+            confighome = os.environ["APPDATA"]
+        elif "XDG_CONFIG_HOME" in os.environ:
+            confighome = os.environ["XDG_CONFIG_HOME"]
         else:
-            confighome = os.path.join(os.environ['HOME'], '.config')
-        configpath = os.path.join(confighome, 'gpterminator', 'config.ini')
+            confighome = os.path.join(os.environ["HOME"], ".config")
+        configpath = os.path.join(confighome, "gpterminator", "config.ini")
         self.config_path = configpath
 
-
     def loadConfig(self):
-        self.getConfigPath();
+        self.getConfigPath()
         config = configparser.ConfigParser()
         config.read(self.config_path)
         self.config_selected = config["SELECTED_CONFIG"]["ConfigName"]
@@ -89,7 +88,6 @@ class GPTerminator:
                 json.dump(self.msg_hist, f, indent=4)
             self.console.print(f"[bright_black]Saved file as {user_in}.json[/]")
 
-
     def copyCode(self):
         last_resp = self.msg_hist[-1]["content"]
         code_block_list = []
@@ -165,7 +163,7 @@ class GPTerminator:
         self.prompt_count = 0
         self.msg_hist = save
         for msg in save:
-            role = msg['role']
+            role = msg["role"]
             if role == "user":
                 self.console.print(
                     f"[yellow]|{self.prompt_count}|[/][bold green] Input [/bold green][bold gray]> [/bold gray]",
@@ -175,12 +173,19 @@ class GPTerminator:
                 self.prompt_count += 1
             elif role == "assistant":
                 encoding = tiktoken.encoding_for_model(self.model)
-                num_tokens = len(encoding.encode(msg['content']))
+                num_tokens = len(encoding.encode(msg["content"]))
                 subtitle_str = f"[bright_black]Tokens:[/] [bold red]{num_tokens}[/]"
-                md = Panel(Markdown(msg['content']), border_style="bright_black", title="[bright_black]Assistant[/]", title_align="left", subtitle=subtitle_str, subtitle_align="right")
+                md = Panel(
+                    Markdown(msg["content"]),
+                    border_style="bright_black",
+                    title="[bright_black]Assistant[/]",
+                    title_align="left",
+                    subtitle=subtitle_str,
+                    subtitle_align="right",
+                )
                 self.console.print(md)
                 self.console.print()
-            else: 
+            else:
                 pass
 
     def setConfig(self):
@@ -235,7 +240,11 @@ class GPTerminator:
         ) as status:
             status.update(status="[bright_black]Generating image...[/]")
             img_response = openai.Image.create(prompt=user_in, n=1, size="1024x1024")
-        image_url = img_response["data"][0]["url"]
+            image_url = img_response["data"][0]["url"]
+            resp = requests.get(image_url, stream=True)
+            cli_image = climage.convert(resp.raw, is_unicode=True)
+        self.console.print(f"[bold green]Image preview:[/]")
+        print(cli_image)
         self.console.print(f"[bold green]Link: [/][bright_black]{image_url}[/]")
         pyperclip.copy(image_url)
         self.console.print(f"[bright_black]Image link copied to clipboard![/]")
@@ -327,8 +336,15 @@ class GPTerminator:
         collected_messages = []
         subtitle_str = f"[bright_black]Tokens:[/] [bold red]{0}[/] | "
         subtitle_str += f"[bright_black]Time Elapsed:[/][bold yellow] {0.0}s [/]"
-        md = Panel(Markdown(""), border_style="bright_black", title="[bright_black]Assistant[/]", title_align="left", subtitle=subtitle_str, subtitle_align="right")
-        
+        md = Panel(
+            Markdown(""),
+            border_style="bright_black",
+            title="[bright_black]Assistant[/]",
+            title_align="left",
+            subtitle=subtitle_str,
+            subtitle_align="right",
+        )
+
         start_time = time.time()
 
         with Live(md, console=self.console, transient=True) as live:
@@ -344,7 +360,14 @@ class GPTerminator:
                 time_elapsed_s = time.time() - start_time
                 subtitle_str = f"[bright_black]Tokens:[/] [bold red]{num_tokens}[/] | "
                 subtitle_str += f"[bright_black]Time Elapsed:[/][bold yellow] {time_elapsed_s:.1f}s [/]"
-                md = Panel(Markdown(full_reply_content), border_style="bright_black", title="[bright_black]Assistant[/]", title_align="left", subtitle=subtitle_str, subtitle_align="right")
+                md = Panel(
+                    Markdown(full_reply_content),
+                    border_style="bright_black",
+                    title="[bright_black]Assistant[/]",
+                    title_align="left",
+                    subtitle=subtitle_str,
+                    subtitle_align="right",
+                )
                 live.update(md)
         self.console.print(md)
         self.console.print()
@@ -370,7 +393,51 @@ class GPTerminator:
             f"[bright_black]Type '{self.cmd_init}quit' to quit the program; '{self.cmd_init}help' for a list of cmds[/]\n"
         )
 
+    def checkDirs(self):
+
+        # get paths
+        if "APPDATA" in os.environ:
+            confighome = os.environ["APPDATA"]
+        elif "XDG_CONFIG_HOME" in os.environ:
+            confighome = os.environ["XDG_CONFIG_HOME"]
+        else:
+            confighome = os.path.join(os.environ["HOME"], ".config")
+        configpath = os.path.join(confighome, "gpterminator")
+        savespath = os.path.join(configpath, "saves")
+
+        #check if paths/files exist
+        config_exists = os.path.exists(os.path.join(configpath, "config.ini"))
+        configpath_exists = os.path.exists(configpath)
+        saves_exist = os.path.exists(savespath)
+
+        if configpath_exists == False:
+            self.console.print(f"[bright_black]Initializing config path ({configpath})...[/]")
+            os.mkdir(configpath)
+
+        # make paths/files
+        if config_exists == False:
+            full_config_path = os.path.join(configpath, "config.ini")
+            self.console.print(f"[bright_black]Initializing config file ({full_config_path})...[/]")
+            config = configparser.ConfigParser()
+            config["SELECTED_CONFIG"] = {"configname": "BASE_CONFIG"}
+            config["BASE_CONFIG"] = {
+                "ModelName": "gpt-3.5-turbo",
+                "Temperature": "1",
+                "PresencePenalty": "0",
+                "FrequencyPenalty": "0",
+                "SystemMessage": "You are a helpful assistant named GPTerminator.",
+                "CommandInitiator": "!",
+                "SavePath": f"{savespath}",
+            }
+            with open(full_config_path, "w") as configfile:
+                config.write(configfile)
+        
+        if saves_exist == False:
+            self.console.print(f"[bright_black]Initializing save path ({savespath})...[/]")
+            os.mkdir(savespath)
+
     def run(self):
+        self.checkDirs()
         self.loadConfig()
         if not os.path.exists(self.save_path):
             os.makedirs(self.save_path)
